==> gutenbrowser_0.6.8.3.orig.tar.gz: gutenbrowser-0.6.8.3/optionsDialog.h <==
/***************************************************************************
                          optionsDialog.h  -  description
                             -------------------
    begin                : Tue Jul 25 2000
    copyright            : (C) 2000 by llornkcor
    email                : ljp@llornkcor.com
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef OPTIONSDIALOG_H
#define OPTIONSDIALOG_H

#include "gutenbrowser.h"
#include "CConfigFile.h"
//#include "styles.h"

#include <qvariant.h>
#include <qdialog.h>
class QVBoxLayout; 
class QHBoxLayout; 
class QGridLayout; 
class QCheckBox;
class QComboBox;
class QLabel;
class QListBox;
class QListBoxItem;
class QPushButton;
class QTabWidget;
class QWidget;

class optionsDialog : public QDialog
{ 
    Q_OBJECT

        public:
    optionsDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~optionsDialog();

    QPushButton* buttonHelp;
    QListBox* listBox;
    QPushButton* buttonOk;
    QTabWidget* tabWidget;
    QWidget* Widget2;
    QCheckBox* Ftp_CheckBox;
    QCheckBox* IconsCheckBox;
    QCheckBox* Http_CheckBox;
    QWidget* Widget3;
        QCheckBox* cb_queryExit;
        bool b_qExit;
    QLabel* TextLabel2;
    QLabel* TextLabel3;
    QListBox* ftp_QListBox_1;
    QPushButton* ftp_DownloadButton;
    QWidget* tab;
    QLabel* TextLabel3_3;
    QLabel* TextLabel4;
    QLabel* TextLabel5;
    QPushButton* PushButton_Browse;
    QComboBox* ComboBox1;
    QComboBox* ComboBoxStyle;
    QListBox* http_ListBox1;
    /////////////////////////////////////////////////////

    void initDialog();
    void initConnections();

    CConfigFile *config;
    QString ftp_base_dir;
    QString ftp_host;
    QString brow;
    QString local_library;

    // ftpsite
    bool useIcon;
    bool parseFtpList(QString outputFile);
    QString ftpSite;  
    QString ListFile;
    QString s_site;
    QString host, base_dir;  
    QString browserName;
    int styleInt;
  bool styleChanged;
    
protected:
    void openSiteList();
    void doOptions();
    void ftpSiteDlg();
    void BrowserDlg();
public slots:
    void getConfig();
    void writeConfig();
    void iconCheckB();
    void getSite();
    void select_site( const char *index );
    void getSelection(  QListBoxItem *item);
        
private slots:
    void OnExit();
    void onTab(int index);
    void slotQueryExit();

protected slots:
        //    virtual void OnOK();
    void listBoxMainSel( int index);
    void setStyle( int index);

    virtual void OptionsFtpClicked();
    virtual void httpCheckB();
    virtual void FtpCheckB();
    //  virtual void goBrowser(const QString&);
    //    virtual void chooseBrowser();
    void select_title(int index);
    void BrowseSelected();


};

#endif // OPTIONSDIALOG_H

==> gutenbrowser_0.8.1.orig.tar.gz: gutenbrowser-0.8.1/optionsDialog.h <==
/***************************************************************************
                          optionsDialog.h  -  description
                             -------------------
    begin                : Tue Jul 25 2000
    copyright            : (C) 2000 by llornkcor
    email                : ljp@llornkcor.com
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef OPTIONSDIALOG_H
#define OPTIONSDIALOG_H

#include "gutenbrowser.h"
#include "CConfigFile.h"
//#include "/*style*/s.h"

#include <qvariant.h>
#include <qdialog.h>
class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QCheckBox;
class QComboBox;
class QLabel;
class QListBox;
class QListBoxItem;
class QListView;
class QListViewItem;
class QPushButton;
class QTabWidget;
class QWidget;

class optionsDialog : public QDialog {
    Q_OBJECT

public:
    optionsDialog( QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
    ~optionsDialog();

    QPushButton* buttonHelp;
    QListBox* listBox;
    QPushButton* buttonOk;
    QTabWidget* tabWidget;
    QWidget*Widget2, *Widget3, *Widget4;
    QCheckBox* Ftp_CheckBox;
    QCheckBox* IconsCheckBox;
    QCheckBox* Http_CheckBox;
    QString s_Wrap;

#ifndef Q_WS_QWS

    QCheckBox* useSplit_CheckBox;
#else

    QCheckBox* useWordWrap_CheckBox;
#endif

    QCheckBox* cb_queryExit;
    bool b_qExit;
    QLabel* TextLabel2;
    QLabel* TextLabel3;
    //    QListBox* ftp_QListBox_1;
    QListView *ftp_QListBox_1;
    QPushButton* ftp_DownloadButton;

    QLabel* TextLabel3_3;
    QLabel* TextLabel4;
    QLabel* TextLabel5;
    QPushButton* PushButton_Browse;
    QComboBox* ComboBox1;
//    QComboBox* ComboBoxStyle;
    QListBox* http_ListBox1;
    /////////////////////////////////////////////////////

    void initDialog();
    void initConnections();

    CConfigFile *config;
    QString ftp_base_dir;
    QString ftp_host;
    QString brow;
    QString local_library;

    // ftpsite
    bool useIcon;
    QString ftpSite;
    QString ListFile;
    QString s_site;
    QString host, base_dir;
    QString browserName;

protected:
    void openSiteList();
    void doOptions();
    void ftpSiteDlg();
    void BrowserDlg();
public slots:
    void getConfig();
    void writeConfig();
    void iconCheckB();
    void getSite();
    void select_site( const char *index );
    void getSelection( QListViewItem *item);

private slots:
    void OnExit();
    void onTab(int index);
    void slotQueryExit();

protected slots:
    void listBoxMainSel( int index);
    virtual void OptionsFtpClicked();
    virtual void slotUseSplit();
    void select_title(int index);
    void BrowseSelected();


};

#endif // OPTIONSDIALOG_H
